#
# spec file for package casync
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           casync
Version:        2+git20201210.bd8898e
Release:        2.5
Summary:        Content Addressable Data Synchronization Tool
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/File-Sharing
URL:            https://github.com/systemd/casync
Source0:        %{name}-%{version}.tar.xz
# PATH-FIX-OPENSUSE compiler_error_nonnull.patch -- fix for nonnull gcc error, see https://github.com/systemd/casync/issues/83
Patch0:         compiler_error_nonnull.patch
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libcurl) >= 7.32.0
BuildRequires:  pkgconfig(liblzma) >= 5.1.0
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(zlib)
# For test suite:
BuildRequires:  rsync
#ExclusiveArch:  x86_64

%description
casync provides a way to efficiently transfer files which change over
time over the Internet. It will split a given set into a git-inspired
content-addressable set of smaller compressed chunks, which can then
be conveniently transferred using HTTP. On the receiving side, these
chunks will be uncompressed and merged together to recreate the
original data. When the original data is modified, only the new chunks
have to be transferred during an update.

%prep
%autosetup -p1

%build
%meson
%meson_build

%check
%{meson_test}

%install
%meson_install

%files
%license LICENSE.LGPL2.1
%doc NEWS README.md TODO
%{_bindir}/casync
%dir %{_prefix}/lib/casync
%dir %{_prefix}/lib/casync/protocols
%{_prefix}/lib/casync/protocols/casync-ftp
%{_prefix}/lib/casync/protocols/casync-sftp
%{_prefix}/lib/casync/protocols/casync-http
%{_prefix}/lib/casync/protocols/casync-https
%{_prefix}/lib/udev/rules.d/75-casync.rules
%{_mandir}/man1/casync.1%{?ext_man}
%{_datadir}/bash-completion/completions/casync

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Mar 12 2021 Thorsten Kukuk <kukuk@suse.com>
- Cleanup build dependencies
* Fri Mar 12 2021 kukuk@suse.com
- Update to version 2+git20201210.bd8898e:
  * docs: fix simple typo, distuingish -> distinguish
  * caprotocol: fix typo in protocol description
  * Call stat again after changing ownership of created files, so we detect reset setuid/setgid bits and reset them.
  * We erroneously use the st_dev value in place of the magic value if the st_dev value is cached. This causes problems extracting trees containing subvolumes.
  * Update to Fedora31
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: Allow OBS to
  shortcut through the -minif lavors.
- Drop libudev-devel BuildRequires: we already have the aequivalent
  pkgconfig(libudev) in place.
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- fix build by adding build requirement on c++ compiler
* Sun Jul 28 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to revision a8f6c841 because of build errors on Tumbleweed.
  - No changelog available.
- remove fix-gcc9-renameat.patch
* Mon May 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing zlib requirement.
* Sat Mar 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-gcc9-renameat.patch from upstream PR#160 to fix boo#1121387
* Mon Feb  5 2018 sebix+novell.com@sebix.at
- specfile:
  - remove test condition
  - remove LANG export for test, done by meson
* Mon Feb  5 2018 sebix+novell.com@sebix.at
- specfile: remove manual manpage build, done by meson
* Sun Feb  4 2018 jengelh@inai.de
- Fix typographic issues in description.
* Fri Feb  2 2018 sebix+novell.com@sebix.at
- add missing group
- run spec-cleaner
* Sun Sep 17 2017 sebix+novell.com@sebix.at
- update to version 2
  * casync now supports retrieving index and chunk data from sftp:// URLs. (In
  addition to the existing ftp://, http:// and https:// support).
  * casync will now honour $TMP if it is set, for placing temporary files and
  directories.
  * casync now saves/restores basic btrfs subvolume information. (Specifically it
  will store whether a directory is a subvolume, and whether it has the
  read-only bit set.) Control this metadata option with the new
  - -with=subvolume/--without=subvolume and
  - -with=subvolume-ro/--without=subvolume-ro switches.
  * casync now saves/restores SELinux label information. Control this metadata
  option with the new --with=selinux/--without=selinux switches.
  * The libgcrypt dependency has been replaced with an OpenSSL dependency, as
  that appears to be better supported today, and may be used to generate
  SHA512/256 hashes (see below).
  * casync now permits selecting the hash function to use with the new --digest=
  option. SHA512/256 is now supported in addition to the old SHA256 algorithm,
  which continues to be supported. The new default however is SHA512/256, as it
  is substantially faster at otherwise equal properties on today's 64bit
  processors. In specific environments SHA256 might perform better, hence both
  algorithms remain supported. Index files contain information about the hash
  algorithm used, hence automatic compatibility is retained.
  * casync now permits selecting the compression format to use with the new
  option --compression=. In addition to the originally reported xz compression,
  gzip and zstd compression are now supported, the latter being the new default
  as it provides excellent compression at very high speeds. It's OK to mix
  chunks compressed with different algorithms in the same store, but of course
  clients downloading them need to be new enough to read chunks in non-xz
  formats. Note that the file suffix for compressed chunks changed ".xz" →
  ".cacnk", as they now may contain either compression, and continuing to use
  the ".xz" suffix would be misleading. To retain compatibility with older
  casync, the environment variable $CASYNC_COMPRESSED_CHUNK_SUFFIX may be set
  to ".xz", to force usage of the old suffix.
  * When extracting archives or archive indexes a subset of the metadata stored
  in the archive may now be selected to be replayed, using the usual --with=
  and --without= options. For example, if an archive containing full metadata
  is extracted with --without=privileged only the unprivileged metadata fields
  are extracted (i.e. no file ownership, ACLs, SELinux labels, ...).
  * After completing an operation statistics about downloaded chunks are now
  shown.
  * When invoking "casync mkdev" the third parameter may now be an arbitrarily
  selected path below /dev which is then created as a symlink to the block
  device used, and registered with udev. This means the usual device
  enumeration will find the block device under the name picked. Example:
    [#] casync mkdev /somepath/tomy/index-file.caibx /dev/quux
  This will expose the block image /somepath/tomy/index-file.caibx as /dev/quux.
* Thu Jul 27 2017 sebix+novell.com@sebix.at
- update to version 1
  * casync now supports retrieving index and chunk data from sftp:// URLs. (In
    addition to the existing ftp://, http:// and https:// support).
  * casync will now honour $TMP if it is set, for placing temporary files and
    directories.
  * casync now saves/restores basic btrfs subvolume information. (Specifically it
    will store whether a directory is a subvolume, and whether it has the
    read-only bit set.) Control this metadata option with the new
  - -with=subvolume/--without=subvolume and
  - -with=subvolume-ro/--without=subvolume-ro switches.
  * casync now saves/restores SELinux label information. Control this metadata
    option with the new --with=selinux/--without=selinux switches.
  * The libgcrypt dependency has been replaced with an OpenSSL dependency, as
    that appears to be better supported today, and may be used to generate
    SHA512/256 hashes (see below).
  * casync now permits selecting the hash function to use with the new --digest=
    option. SHA512/256 is now supported in addition to the old SHA256 algorithm,
    which continues to be supported. The new default however is SHA512/256, as it
    is substantially faster at otherwise equal properties on today's 64bit
    processors. In specific environments SHA256 might perform better, hence both
    algorithms remain supported. Index files contain information about the hash
    algorithm used, hence automatic compatibility is retained.
  * casync now permits selecting the compression format to use with the new
    option --compression=. In addition to the originally reported xz compression,
    gzip and zstd compression are now supported, the latter being the new default
    as it provides excellent compression at very high speeds. It's OK to mix
    chunks compressed with different algorithms in the same store, but of course
    clients downloading them need to be new enough to read chunks in non-xz
    formats. Note that the file suffix for compressed chunks changed ".xz" →
    ".cacnk", as they now may contain either compression, and continuing to use
    the ".xz" suffix would be misleading. To retain compatibility with older
    casync, the environment variable $CASYNC_COMPRESSED_CHUNK_SUFFIX may be set
    to ".xz", to force usage of the old suffix.
  * When extracting archives or archive indexes a subset of the metadata stored
    in the archive may now be selected to be replayed, using the usual --with=
    and --without= options. For example, if an archive containing full metadata
    is extracted with --without=privileged only the unprivileged metadata fields
    are extracted (i.e. no file ownership, ACLs, SELinux labels, ...).
  * After completing an operation statistics about downloaded chunks are now
    shown.
  * When invoking "casync mkdev" the third parameter may now be an arbitrarily
    selected path below /dev which is then created as a symlink to the block
    device used, and registered with udev. This means the usual device
    enumeration will find the block device under the name picked. Example:
    [#] casync mkdev /somepath/tomy/index-file.caibx /dev/quux
  * This will expose the block image /somepath/tomy/index-file.caibx as /dev/quux.
* Fri Jun 23 2017 sebix+novell.com@sebix.at
- add a959668782dafbfe469994b14d9c3adaef4e1c34.patch to fix tests on various non-64bit platforms
* Wed Jun 21 2017 sebix+novell.com@sebix.at
- initial package
- add pull request 28 as 28.patch to fix the tests for kernels >= 4.11
- add commmit 675e7902e449cc00b0a459a6ec17a0e044ac966b.patch as patch for a manpage
